@@ -18,7 +18,7 @@ class BBox(NamedTuple):
     y: int
     w: int
     h: int
-    angle: float = 0.
+    angle: float = 0.0
 
     @property
     def area(self) -> int:
@@ -57,15 +57,17 @@ class BBox(NamedTuple):
     def from_contour_simplified(cls, contour) -> "BBox":
         x, y, w, h = cv2.boundingRect(contour)
         x, y, w, h = map(int, [x + 0.5 * w, y + 0.5 * h, w, h])
-        return BBox(x, y, w, h, 0.)
+        return BBox(x, y, w, h, 0.0)
 
 
 class ShapeObject(LoggingMixin):
-    def __init__(self,
-                 gray: np.ndarray,
-                 contour: np.ndarray = None,
-                 *,
-                 force_hull: bool = False):
+    def __init__(
+        self,
+        gray: np.ndarray,
+        contour: np.ndarray = None,
+        *,
+        force_hull: bool = False,
+    ):
         self.gray = gray
         self._mask = None
         self._mask_area = None
@@ -145,14 +147,18 @@ class ShapeObject(LoggingMixin):
     def contour_area(self) -> float:
         if self._contour_area is None:
             if self.contour is None or len(self.contour) == 0:
-                self._contour_area = 0.
+                self._contour_area = 0.0
             else:
                 self._contour_area = self.get_contour_area(self.contour)
         return self._contour_area
 
     @property
     def is_valid(self) -> bool:
-        return self.contour is not None and self.contour_area > 0. and self.mask_area < self.canvas_area
+        return (
+            self.contour is not None
+            and self.contour_area > 0.0
+            and self.mask_area < self.canvas_area
+        )
 
     def copy(self) -> "ShapeObject":
         return ShapeObject(self.gray.copy(), self.contour.copy())
@@ -173,20 +179,19 @@ class ShapeObject(LoggingMixin):
         moved = self.move_img(self.gray, dx, dy)
         return ShapeObject(moved, (self.contour + [dx, dy]).astype(np.int))
 
-    def to_tight(self, *,
-                 padding_ratio: float = 0.) -> "ShapeObject":
+    def to_tight(self, *, padding_ratio: float = 0.0) -> "ShapeObject":
         ltx, lty = self.bbox_simplified.left_top
         rbx, rby = self.bbox_simplified.right_bottom
         cropped = self.gray[lty:rby, ltx:rbx]
         cropped_contour = self.contour - [ltx, lty]
-        if padding_ratio <= 0.:
+        if padding_ratio <= 0.0:
             return ShapeObject(cropped, cropped_contour)
         w, h = rbx - ltx, rby - lty
         x_padding = int(padding_ratio * w)
         y_padding = int(padding_ratio * h)
         new_w, new_h = w + 2 * x_padding, h + 2 * y_padding
         canvas = np.zeros([new_h, new_w], np.uint8)
-        canvas[y_padding:y_padding+h, x_padding:x_padding+w] = cropped
+        canvas[y_padding : y_padding + h, x_padding : x_padding + w] = cropped
         canvas_contour = cropped_contour + [x_padding, y_padding]
         return ShapeObject(canvas, canvas_contour)
 
@@ -197,11 +202,13 @@ class ShapeObject(LoggingMixin):
         dx, dy = [tc - cc for tc, cc in zip(target_center, current_center)]
         return self.move(dx, dy)
 
-    def match_center(self,
-                     template: "ShapeObject",
-                     *,
-                     use_bbox: bool = False,
-                     return_dxy: bool = False) -> Union["ShapeObject", Tuple[float, float]]:
+    def match_center(
+        self,
+        template: "ShapeObject",
+        *,
+        use_bbox: bool = False,
+        return_dxy: bool = False,
+    ) -> Union["ShapeObject", Tuple[float, float]]:
         if not use_bbox:
             current_center = self.contour_center
             target_center = template.contour_center
@@ -213,28 +220,38 @@ class ShapeObject(LoggingMixin):
             return dx, dy
         return self.move(dx, dy)
 
-    def separate(self,
-                 *,
-                 min_area_threshold: float = 0.01,
-                 **kwargs) -> List["ShapeObject"]:
+    def separate(
+        self, *, min_area_threshold: float = 0.01, **kwargs
+    ) -> List["ShapeObject"]:
         fg = self.gray >= 127
         bgx, bgy = np.vstack(np.nonzero(~fg))[..., 0]
         n_areas, areas_map = cv2.connectedComponents(self.gray)
         area_threshold = min_area_threshold * fg.sum()
         masks = [areas_map == i for i in range(n_areas) if i != areas_map[bgx, bgy]]
-        thresholds = list(map(
-            lambda mask: mask.astype(np.uint8) * 255,
-            filter(lambda mask: mask.sum() > area_threshold, masks)
-        ))
+        thresholds = list(
+            map(
+                lambda mask: mask.astype(np.uint8) * 255,
+                filter(lambda mask: mask.sum() > area_threshold, masks),
+            )
+        )
         return [ShapeObject(threshold, **kwargs) for threshold in thresholds]
 
     def get_scaled_img(self, scale: float, align_bottom: bool):
         return self.scale_img(
-            self.gray, self.contour_center, scale,
-            bbox=self.bbox_simplified, align_bottom=align_bottom
+            self.gray,
+            self.contour_center,
+            scale,
+            bbox=self.bbox_simplified,
+            align_bottom=align_bottom,
         )
 
-    def get_scaled_contour(self, w_scale, h_scale=None, *, canvas_changed=False) -> np.ndarray:
+    def get_scaled_contour(
+        self,
+        w_scale,
+        h_scale=None,
+        *,
+        canvas_changed=False,
+    ) -> np.ndarray:
         if h_scale is None:
             h_scale = w_scale
         cx, cy = self.contour_center
@@ -249,19 +266,25 @@ class ShapeObject(LoggingMixin):
         scores = {}
         for method_num in [1, 2, 3]:
             score = cv2.matchShapes(src, tgt, method_num, 0.0)
-            scores[str(method_num)] = max(0., 10. - score)
+            scores[str(method_num)] = max(0.0, 10.0 - score)
         return scores
 
-    def get_match_scores(self,
-                         template: "ShapeObject",
-                         matching_method: Union[str, Callable, List[Union[str, Callable]]] = "contour_all",
-                         **kwargs) -> Dict[str, float]:
+    def get_match_scores(
+        self,
+        template: "ShapeObject",
+        matching_method: Union[
+            str, Callable, List[Union[str, Callable]]
+        ] = "contour_all",
+        **kwargs,
+    ) -> Dict[str, float]:
 
         if kwargs.get("trigger_logging", False):
             self._init_logging()
 
         def _raise():
-            raise NotImplementedError(f"matching_method '{matching_method}' not defined")
+            raise NotImplementedError(
+                f"matching_method '{matching_method}' not defined"
+            )
 
         scores = defaultdict(float)
         matching_methods = matching_method
@@ -272,33 +295,49 @@ class ShapeObject(LoggingMixin):
             with timing_context(self, matching_method):
                 local_scores = {}
                 if callable(matching_method):
-                    local_scores["mean"] = matching_method(self.contour, template.contour)
+                    local_scores["mean"] = matching_method(
+                        self.contour, template.contour
+                    )
                 elif "contour" in matching_method:
                     if matching_method == "contour_all":
-                        local_scores.update(self._fetch_match_shape_scores(self.contour, template.contour))
+                        local_scores.update(
+                            self._fetch_match_shape_scores(
+                                self.contour, template.contour
+                            )
+                        )
                     elif matching_method == "contour_assignment":
                         with timing_context(self, "template resize"):
                             template_resized = template.resize(self.wh)
                         with timing_context(self, "get contour"):
-                            self_contour, resized_contour = self.contour, template_resized.contour
+                            self_contour, resized_contour = (
+                                self.contour,
+                                template_resized.contour,
+                            )
                         with timing_context(self, "diff matrix"):
-                            diff_matrix = self_contour - resized_contour.transpose([1, 0, 2])
+                            resized_transpose = resized_contour.transpose([1, 0, 2])
+                            diff_matrix = self_contour - resized_transpose
                             diff_matrix = np.linalg.norm(diff_matrix, axis=-1)
                         with timing_context(self, "linear sum assignment"):
                             row_ind, col_ind = linear_sum_assignment(diff_matrix)
                         with timing_context(self, "diff from assignment"):
                             diff = diff_matrix[row_ind, col_ind].mean()
                             diff /= math.sqrt(self.wh[0] ** 2 + self.wh[1] ** 2)
-                        local_scores["mean"] = 1. - diff
+                        local_scores["mean"] = 1.0 - diff
                     else:
                         _raise()
                 elif "filled" in matching_method:
-                    resized, template_resized = map(ShapeObject.resize, [self, template])
+                    resized, template_resized = map(
+                        ShapeObject.resize, [self, template]
+                    )
                     gray, template_gray = resized.gray, template_resized.gray
                     if matching_method == "filled_shape_all":
-                        local_scores.update(self._fetch_match_shape_scores(gray, template_gray))
+                        local_scores.update(
+                            self._fetch_match_shape_scores(gray, template_gray)
+                        )
                     elif matching_method == "filled_iou":
-                        local_scores["mean"] = 1. - self.iou_distance(gray, template_gray)
+                        local_scores["mean"] = 1.0 - self.iou_distance(
+                            gray, template_gray
+                        )
                     else:
                         _raise()
                 elif matching_method == "edge":
@@ -307,13 +346,26 @@ class ShapeObject(LoggingMixin):
                     floor = kwargs.get("edge_scale_floor", 0.8)
                     ceiling = kwargs.get("edge_scale_ceiling", 0.8)
                     resize_floor = kwargs.get("edge_resize_floor", 0.5)
-                    resized_template, resized_res = template.resize_to(self, False, tight=True, area_definition="bbox")
+                    resized_template, resized_res = template.resize_to(
+                        self,
+                        False,
+                        tight=True,
+                        area_definition="bbox",
+                    )
                     if resized_res["resize_scale"] <= resize_floor:
                         local_scores["mean"] = -math.inf
                     else:
                         for scale in np.linspace(floor, ceiling, num):
-                            scaled_template = resized_template.rescale(scale, tight=True, scale_contour=False)
-                            match_score = cv2.matchTemplate(self.edge, scaled_template.edge, cv2.TM_CCOEFF_NORMED).max()
+                            scaled_template = resized_template.rescale(
+                                scale,
+                                tight=True,
+                                scale_contour=False,
+                            )
+                            match_score = cv2.matchTemplate(
+                                self.edge,
+                                scaled_template.edge,
+                                cv2.TM_CCOEFF_NORMED,
+                            ).max()
                             local_scores[f"{scale:6.4f}"] = match_score
                 else:
                     _raise()
@@ -333,13 +385,20 @@ class ShapeObject(LoggingMixin):
         return scores
 
     def get_min_distance(self, template: "ShapeObject") -> float:
-        return np.min(np.linalg.norm(self.contour - template.contour[..., 0, :][None, ...], axis=-1))
+        return np.min(
+            np.linalg.norm(
+                self.contour - template.contour[..., 0, :][None, ...],
+                axis=-1,
+            )
+        )
 
-    def resize(self,
-               size: Tuple[float, float] = (300, 300),
-               *,
-               tight: bool = True,
-               keep_aspect_ratio: bool = True) -> "ShapeObject":
+    def resize(
+        self,
+        size: Tuple[float, float] = (300, 300),
+        *,
+        tight: bool = True,
+        keep_aspect_ratio: bool = True,
+    ) -> "ShapeObject":
         sw, sh = size
         if not tight:
             w, h = self.wh
@@ -352,7 +411,11 @@ class ShapeObject(LoggingMixin):
         w_scale, h_scale = sw / w, sh / h
         if not keep_aspect_ratio:
             resized = cv2.resize(target.gray, size)
-            resized_contour = target.get_scaled_contour(w_scale, h_scale, canvas_changed=True)
+            resized_contour = target.get_scaled_contour(
+                w_scale,
+                h_scale,
+                canvas_changed=True,
+            )
         else:
             if w_scale < h_scale:
                 adjust_x = False
@@ -360,27 +423,34 @@ class ShapeObject(LoggingMixin):
             else:
                 adjust_x = True
                 target_scale = h_scale
-            resized_contour = target.get_scaled_contour(target_scale, canvas_changed=True)
-            target_size = tuple(map(int, map(round, [w * target_scale, h * target_scale])))
+            resized_contour = target.get_scaled_contour(
+                target_scale,
+                canvas_changed=True,
+            )
+            target_size = tuple(
+                map(int, map(round, [w * target_scale, h * target_scale]))
+            )
             resized_raw = cv2.resize(target.gray, target_size)
             resized = np.zeros(size, dtype=np.uint8)
             tx, ty = target_size
             if adjust_x:
                 dx = int(0.5 * (sw - tx))
-                resized[:ty, dx:dx + tx] = resized_raw
+                resized[:ty, dx : dx + tx] = resized_raw
                 resized_contour += [dx, 0]
             else:
                 dy = int(0.5 * (sh - ty))
-                resized[dy:dy + ty, :tx] = resized_raw
+                resized[dy : dy + ty, :tx] = resized_raw
                 resized_contour += [0, dy]
         return ShapeObject(resized, resized_contour)
 
-    def rescale(self,
-                scale: float,
-                *,
-                tight: bool = False,
-                align_bottom: bool = False,
-                scale_contour: bool = True) -> "ShapeObject":
+    def rescale(
+        self,
+        scale: float,
+        *,
+        tight: bool = False,
+        align_bottom: bool = False,
+        scale_contour: bool = True,
+    ) -> "ShapeObject":
         dy, scaled = self.get_scaled_img(scale, align_bottom)
         contour = None if not scale_contour else self.get_scaled_contour(scale)
         if contour is not None and align_bottom:
@@ -390,13 +460,15 @@ class ShapeObject(LoggingMixin):
             scaled_obj = scaled_obj.to_tight()
         return scaled_obj
 
-    def resize_to(self,
-                  template: "ShapeObject",
-                  match_center: bool,
-                  *,
-                  tight: bool = False,
-                  scale_ceiling: int = None,
-                  area_definition: str = "contour") -> Union[None, Tuple["ShapeObject", Dict[str, float]]]:
+    def resize_to(
+        self,
+        template: "ShapeObject",
+        match_center: bool,
+        *,
+        tight: bool = False,
+        scale_ceiling: int = None,
+        area_definition: str = "contour",
+    ) -> Union[None, Tuple["ShapeObject", Dict[str, float]]]:
         """
         将 self.contour 缩放，使得缩放后与 template.contour 的面积相同
         :param template：
@@ -410,13 +482,17 @@ class ShapeObject(LoggingMixin):
         (w, h), (wt, ht) = self.wh, template.wh
         w_scale, h_scale = wt / w, ht / h
         resized = cv2.resize(self.gray, (wt, ht))
-        new_obj = ShapeObject(resized, self.get_scaled_contour(w_scale, h_scale, canvas_changed=True))
+        new_obj = ShapeObject(
+            resized, self.get_scaled_contour(w_scale, h_scale, canvas_changed=True)
+        )
         if area_definition == "contour":
             template_area, new_area = template.contour_area, new_obj.contour_area
         elif area_definition == "bbox":
             template_area, new_area = template.bbox.area, new_obj.bbox.area
         else:
-            raise NotImplementedError(f"area_definition '{area_definition}' is not defined")
+            raise NotImplementedError(
+                f"area_definition '{area_definition}' is not defined"
+            )
         scale = (template_area / new_area) ** 0.5
         if scale_ceiling is not None and scale >= scale_ceiling:
             return
@@ -424,29 +500,31 @@ class ShapeObject(LoggingMixin):
         scaled_obj = ShapeObject(scaled, new_obj.get_scaled_contour(scale))
         if tight:
             if match_center:
-                print(f"Warning : match_center will not take effect because tight=True")
+                print("Warning : match_center will not take effect because tight=True")
             scaled_obj = scaled_obj.to_tight()
         elif match_center:
             scaled_obj = scaled_obj.match_center(template)
         return scaled_obj, {"resize_scale": scale}
 
-    def rotate_to(self,
-                  template: "ShapeObject",
-                  rotated_per_itr: int = 10,
-                  distance_choice: str = "iou",
-                  match_center: bool = True,
-                  theta_floor: int = 0,
-                  theta_ceiling: int = 360,
-                  scale_ceiling: int = None) -> Union[None, Tuple["ShapeObject", Dict[str, float]]]:
+    def rotate_to(
+        self,
+        template: "ShapeObject",
+        rotated_per_itr: int = 10,
+        distance_choice: str = "iou",
+        match_center: bool = True,
+        theta_floor: int = 0,
+        theta_ceiling: int = 360,
+        scale_ceiling: int = None,
+    ) -> Union[None, Tuple["ShapeObject", Dict[str, float]]]:
 
         # 可以选择不同的distance function来定义匹配效果的好坏
-        distance_function = {
-            "iou": self.iou_distance
-        }
+        distance_function = {"iou": self.iou_distance}
 
         # 将 self.gray 缩放并将中心位置移到 template_img 的中心位置
         template_img = template.gray
-        resize_result = self.resize_to(template, match_center, scale_ceiling=scale_ceiling)
+        resize_result = self.resize_to(
+            template, match_center, scale_ceiling=scale_ceiling
+        )
         if resize_result is None:
             return
         resized, resize_res = resize_result
@@ -471,7 +549,11 @@ class ShapeObject(LoggingMixin):
                 min_loss = cur_loss
                 min_theta = theta
                 rotated_img = tmp
-        res = {"theta": min_theta, "loss": min_loss, "resize_scale": resize_res["resize_scale"]}
+        res = {
+            "theta": min_theta,
+            "loss": min_loss,
+            "resize_scale": resize_res["resize_scale"],
+        }
         return ShapeObject(rotated_img), res
 
     def save_img(self, saving_path):
@@ -514,16 +596,20 @@ class ShapeObject(LoggingMixin):
         :return: 重心坐标
         """
         m = cv2.moments(contour)
-        m00 = max(m['m00'], 1e-5)
-        cx = int(m['m10'] / m00)
-        cy = int(m['m01'] / m00)
+        m00 = max(m["m00"], 1e-5)
+        cx = int(m["m10"] / m00)
+        cy = int(m["m01"] / m00)
         return cx, cy
 
     @staticmethod
-    def scale_img(img, center, scale,
-                  *,
-                  bbox: BBox = None,
-                  align_bottom: bool = False):
+    def scale_img(
+        img,
+        center,
+        scale,
+        *,
+        bbox: BBox = None,
+        align_bottom: bool = False,
+    ):
         """
         对输入的图像，在其中心位置进行缩放
         :param img:
