@@ -374,7 +374,7 @@ def register_core(
         registered = global_dict.get(name)
         if registered is not None:
             print(
-                f"~~~ [warning] '{name}' has already registered "
+                f"{LoggingMixin.warning_prefix}'{name}' has already registered "
                 f"in the given global dict ({global_dict})"
             )
             return cls
@@ -719,9 +719,9 @@ class LoggingMixin:
     )
     _timing_dict_, _time_cache_dict_ = {}, {}
 
-    info_prefix = "~~~  [ info ] "
-    warning_prefix = "~~~ [warning] "
-    error_prefix = "~~~ [ error ] "
+    info_prefix = ">  [ info ] "
+    warning_prefix = "> [warning] "
+    error_prefix = "> [ error ] "
 
     @property
     def logging_path(self):
@@ -779,7 +779,7 @@ class LoggingMixin:
         if self._logging_path_ is None:
             self._logging_path_ = config["_logging_path_"] = self.logging_path
         os.makedirs(os.path.dirname(self.logging_path), exist_ok=True)
-        file_handler = logging.FileHandler(self.logging_path)
+        file_handler = logging.FileHandler(self.logging_path, encoding="utf-8")
         file_handler.setFormatter(self._formatter_)
         file_handler.setLevel(logging.DEBUG)
         console = logging.StreamHandler()
@@ -894,6 +894,8 @@ class LoggingMixin:
         cls._triggered_ = False
         cls._initialized_ = False
         cls._logging_path_ = None
+        if cls._logger_ is not None:
+            cls._release_handlers(cls._logger_)
         cls._logger_ = cls._verbose_level_ = None
         cls._timing_dict_, cls._time_cache_dict_ = {}, {}
 
@@ -1235,15 +1237,17 @@ class Saving(LoggingMixin):
         return True
 
     @staticmethod
-    def save_dict(d: dict, name: str, folder: str):
+    def save_dict(d: dict, name: str, folder: str) -> str:
         if Saving._check_dict(d):
             kwargs = {}
             suffix, method, mode = ".json", json.dump, "w"
         else:
             kwargs = {"recurse": True}
             suffix, method, mode = Saving.dill_suffix, dill.dump, "wb"
-        with open(os.path.join(folder, f"{name}{suffix}"), mode) as f:
+        file = os.path.join(folder, f"{name}{suffix}")
+        with open(file, mode) as f:
             method(d, f, **kwargs)
+        return os.path.abspath(file)
 
     @staticmethod
     def load_dict(name: str, folder: str = None):
@@ -1731,7 +1735,7 @@ class timeit(context_error_handler):
     --------
     >>> with timeit("something"):
     >>>     # do something here
-    >>> # will print "~~~  [ info ] timing for    something     : x.xxxx"
+    >>> # will print ">  [ info ] timing for    something     : x.xxxx"
 
     """
 
@@ -1922,7 +1926,7 @@ class lock_manager(context_error_handler, LoggingMixin):
                 if os.path.isfile(stuff):
                     self.log_msg(
                         f"clearing cached file: {stuff}",
-                        "~~~~~~ ",
+                        ">> ",
                         5,
                         logging.ERROR,
                         frame,
@@ -1931,7 +1935,7 @@ class lock_manager(context_error_handler, LoggingMixin):
                 elif os.path.isdir(stuff):
                     self.log_msg(
                         f"clearing cached directory: {stuff}",
-                        "~~~~~~ ",
+                        ">> ",
                         5,
                         logging.ERROR,
                         frame,
@@ -1949,7 +1953,7 @@ class lock_manager(context_error_handler, LoggingMixin):
 
     @property
     def cache_stuffs_str(self):
-        return "\n".join([f"~~~~~~ {stuff}" for stuff in self._stuffs])
+        return "\n".join([f">> {stuff}" for stuff in self._stuffs])
 
     @property
     def exception_suffix(self):
