@@ -191,7 +191,7 @@ class Metrics(LoggingMixin):
         if requires_prob:
             cls.requires_prob_metrics.add(name)
 
-    def metric(self, y, pred):
+    def metric(self, y, pred, **kwargs: Any):
         if self.type is None:
             msg = "`score` method was called but type is not specified in Metrics"
             raise ValueError(msg)
@@ -200,8 +200,8 @@ class Metrics(LoggingMixin):
             return float("nan")
         custom_metric_info = self.custom_metrics.get(self.type)
         if custom_metric_info is not None:
-            return custom_metric_info["f"](self, y, pred)
-        return getattr(self, self.type)(y, pred)
+            return custom_metric_info["f"](self, y, pred, **kwargs)
+        return getattr(self, self.type)(y, pred, **kwargs)
 
     # config-dependent metrics
 
@@ -327,7 +327,7 @@ class Estimator(LoggingMixin):
     >>> x, y = map(np.atleast_2d, [[1., 2., 3.], [0., 2., 1.]])
     >>> identical = lambda x_: x_
     >>> minus_one = lambda x_: x_ - 1
-    >>> # ~~~  [ info ] Results
+    >>> # >  [ info ] Results
     >>> # ==========================================================
     >>> # |             identical  |    mae     |  1.000000  |
     >>> # |             minus_one  |    mae     |  0.666667  |  <-
@@ -720,12 +720,12 @@ class Comparer(LoggingMixin):
     >>>     "minus_one": ModelPattern(predict_method=minus_one)
     >>> }
     >>> estimators = [Estimator("mse"), Estimator("mae")]
-    >>> # ~~~  [ info ] Results
+    >>> # >  [ info ] Results
     >>> # ==========================================================
     >>> # |             identical  |    mse     |  1.666667  |
     >>> # |             minus_one  |    mse     |  0.666667  |  <-
     >>> # ----------------------------------------------------------
-    >>> # ~~~  [ info ] Results
+    >>> # >  [ info ] Results
     >>> # ==========================================================
     >>> # |             identical  |    mae     |  1.000000  |
     >>> # |             minus_one  |    mae     |  0.666667  |  <-
